==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/jms/jca/ListenerEndpoint.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.jms.jca;

import com.caucho.log.Log;

import javax.jms.Message;
import javax.jms.MessageListener;
import javax.resource.spi.endpoint.MessageEndpoint;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * The JMS MessageListener endpoint
 */
public class ListenerEndpoint implements MessageEndpoint, MessageListener {
  private static final Logger log = Log.open(ListenerEndpoint.class);

  private MessageListener _listener;
  
  /**
   * Sets the listener.
   */
  public void setListener(MessageListener listener)
  {
    _listener = listener;
  }
  
  /**
   * Called by a resource adapter before a message is delivered.
   */
  public void beforeDelivery(java.lang.reflect.Method method)
  {
  }

  /**
   * Called by a resource adapter after a message is delivered.
   */
  public void afterDelivery()
  {
  }

  /**
   * Runs the endpoint.
   */
  public void onMessage(Message message)
  {
    try {
      MessageListener listener = _listener;
      
      if (listener != null)
	listener.onMessage(message);
    } catch (Throwable e) {
      log.log(Level.WARNING, e.toString(), e);
    }
  }

  /**
   * Called when the resource adapter doesn't need a proxy endpoint.
   */
  public void release()
  {
    _listener = null;
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/resin/src/com/caucho/jms/jca/ListenerEndpoint.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.jms.jca;

import javax.jms.Message;
import javax.jms.MessageListener;
import javax.resource.spi.endpoint.MessageEndpoint;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * The JMS MessageListener endpoint
 */
public class ListenerEndpoint implements MessageEndpoint, MessageListener {
  private static final Logger log 
    = Logger.getLogger(ListenerEndpoint.class.getName());

  private MessageListener _listener;
  
  /**
   * Sets the listener.
   */
  public void setListener(MessageListener listener)
  {
    _listener = listener;
  }
  
  /**
   * Called by a resource adapter before a message is delivered.
   */
  public void beforeDelivery(java.lang.reflect.Method method)
  {
  }

  /**
   * Called by a resource adapter after a message is delivered.
   */
  public void afterDelivery()
  {
  }

  /**
   * Runs the endpoint.
   */
  public void onMessage(Message message)
  {
    try {
      MessageListener listener = _listener;
      
      if (listener != null)
        listener.onMessage(message);
    } catch (Throwable e) {
      log.log(Level.WARNING, e.toString(), e);
    }
  }

  /**
   * Called when the resource adapter doesn't need a proxy endpoint.
   */
  public void release()
  {
    _listener = null;
  }
}
